Flask-Dance — Flask Dance 0.5.0 documentation

# Flask-Dance

Doing the OAuth dance with style using Flask, requests, and oauthlib. Currently, only OAuth consumers are supported, but this project could easily support OAuth providers in the future, as well.

User Guide:

- Quickstarts
  - GitHub Quickstart
  - Google Quickstart
  - SQLAlchemy Multi-User Quickstart
- Providers
  - GitHub
  - Google
  - Twitter
  - JIRA
  - Custom
- Backends
  - SQLAlchemy
  - Custom
- Signals

Advanced Topics:

- How OAuth Works
  - Definitions
  - OAuth 2
  - OAuth 1
  - Dance Complete
- Developer Interface
  - Consumers
  - Backends

# Indices and tables

- Index
- Module Index
- Search Page